package at.kugel.tool.buildtray;

import at.kugel.tool.buildtray.action.Actions;
import at.kugel.tool.buildtray.action.HtmlRegularExpressionActions;
import at.kugel.tool.buildtray.action.StringIOHelper;
import at.kugel.tool.buildtray.config.Config;
import at.kugel.tool.buildtray.config.ReloadingConfig;
import at.kugel.tool.buildtray.status.SetStatusAble;
import at.kugel.tool.buildtray.status.Status;

/**
 * Loads the build server url with all settings for debug purposes.
 */
public final class CheckConfig {

   public static void main(String[] pArgs) {

      if (pArgs.length != 1) {
         System.out.println("Usage: java " + CheckConfig.class.getName() + " <path to config file e.g. \"config/Hudson-1.2.properties\">");
         System.exit(2);
      }

      final Config conf = new ReloadingConfig(pArgs[0]);

      System.out.println("checking server access...");
      try {
         final String content = new StringIOHelper(conf).readPage();
         System.out.println(content);
      } catch (Exception ex) {
         ex.printStackTrace(System.err);
      }

      System.out.println("checking build status...");
      final Actions actions = new HtmlRegularExpressionActions(conf);
      actions.refresh(new ConsoleStatus());
   }

}

/**
 * Simple console status that just prints last status for debug purposes.
 */
class ConsoleStatus implements SetStatusAble {

   public void setStatus(Status pStatus, String pProjectName, String pDate) {
      System.out.println(pProjectName + " is " + pStatus + ' ' + pDate);
   }

   public void setError(Exception pException) {
      pException.printStackTrace(System.err);
   }

}
