package at.kugel.tool.buildtray.action;

import java.awt.Desktop;
import java.net.URI;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import at.kugel.tool.buildtray.config.Config;
import at.kugel.tool.buildtray.status.SetStatusAble;
import at.kugel.tool.buildtray.status.Status;

/**
 * Implementation of tray actions using regular expressions from the config.
 */
public class HtmlRegularExpressionActions implements Actions {

   private final Config config;

   public HtmlRegularExpressionActions(Config pConfig) {
      config = pConfig;
   }

   private String determineDisplayUrl() {
      String url = config.getServerDisplayUrl();
      if (url == null || url.equals("")) {
         url = config.getServerlUrl();
      }
      return url;
   }

   @Override
   public void openBrowser() {
      try {

         if (Desktop.isDesktopSupported()) {
            final Desktop dt = Desktop.getDesktop();
            if (dt.isSupported(Desktop.Action.BROWSE)) {
               dt.browse(new URI(determineDisplayUrl()));
            }
         }

      } catch (Exception e) {
         handleError(null, e);
      }
   }

   @Override
   public void refresh(SetStatusAble pTray) {
      try {

         final String content = new StringIOHelper(config).readPage();

         if (config.isCheckBusy()) {
            Matcher busyMatcher = Pattern.compile(config.getBusyPattern()).matcher(content);
            if (busyMatcher.find()) {
               final String name = busyMatcher.group(1);
               pTray.setStatus(Status.BUSY, name, null);
               return;
            }
         }

         parseRegular(content, pTray);

      } catch (Exception e) {
         handleError(pTray, e);
      }
   }

   private void parseRegular(String pContent, SetStatusAble pTray) throws ParseException {
      String lastName = null;
      Status lastStatus = Status.OK;
      Date lastDate = new Date(0);

      SimpleDateFormat dateFormat = new SimpleDateFormat(config.getDatePattern());
      Matcher statusMatcher = Pattern.compile(config.getStatusPattern(), Pattern.DOTALL).matcher(pContent);
      while (statusMatcher.find()) {
         final String name = statusMatcher.group(config.getStatusPatternNameGroup());

         final String statusStr = statusMatcher.group(config.getStatusPatternStatusGroup());
         final Status status;
         if (statusStr.matches(config.getSuccessValue())) {
            status = Status.OK;
         } else if (statusStr.matches(config.getFailedValue())) {
            status = Status.FAILED;
         } else {
            status = Status.UNKNOWN;
            continue;
         }

         final Date date = dateFormat.parse(statusMatcher.group(config.getStatusPatternDateGroup()));

         if (date.after(lastDate) && status.ordinal() >= lastStatus.ordinal()) {
            // System.out.println(name + " after " + lastName);
            lastName = name;
            lastStatus = status;
            lastDate = date;
         } else if (status.ordinal() > lastStatus.ordinal()) {
            // System.out.println(name + " worse than " + lastName);
            lastName = name;
            lastStatus = status;
            lastDate = date;
         }

      }
      pTray.setStatus(lastStatus, lastName, dateFormat.format(lastDate));
   }

   private void handleError(SetStatusAble pTray, Exception pException) {
      pTray.setError(pException);
   }

   @Override
   public void exit() {
      System.exit(0);
   }

}
