package at.kugel.tool.buildtray.config;

import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Properties;

public class ReloadingConfig implements Config {

   private final String path;
   private long lastLoaded;
   private final Properties props = new Properties();

   public ReloadingConfig(String pPath) {
      if (pPath == null) {
         throw new IllegalArgumentException("path is null");
      }
      path = pPath;
   }

   private void checkForUpdate() {
      final long lastModified = new File(path).lastModified();
      if (lastLoaded < lastModified) {
         try {
            props.clear();
            final FileReader in = new FileReader(path);
            try {
               props.load(in);
            } finally {
               in.close();
            }
            lastLoaded = lastModified;
         } catch (IOException e) {
            throw new IllegalStateException(e);
         }
      }
   }

   @Override
   public long getPollingMs() {
      checkForUpdate();
      return Integer.parseInt(props.getProperty("polling.ms"));
   }

   @Override
   public String getServerlUrl() {
      checkForUpdate();
      return props.getProperty("server.url");
   }

   @Override
   public String getServerDisplayUrl() {
      checkForUpdate();
      return props.getProperty("server.display");
   }

   @Override
   public boolean isCheckBusy() {
      checkForUpdate();
      return Boolean.valueOf(props.getProperty("busy.check"));
   }

   @Override
   public String getDatePattern() {
      checkForUpdate();
      return props.getProperty("status.date.format");
   }

   @Override
   public long getSplashWaitMs() {
      checkForUpdate();
      return Integer.parseInt(props.getProperty("splash.wait.ms"));
   }

   @Override
   public String getBusyPattern() {
      checkForUpdate();
      return props.getProperty("busy.pattern");
   }

   @Override
   public String getSuccessValue() {
      checkForUpdate();
      return props.getProperty("value.success");
   }

   @Override
   public String getFailedValue() {
      checkForUpdate();
      return props.getProperty("value.failed");
   }

   @Override
   public String getStatusPattern() {
      checkForUpdate();
      return props.getProperty("status.pattern");
   }

   @Override
   public int getStatusPatternNameGroup() {
      checkForUpdate();
      return Integer.parseInt(props.getProperty("status.name.group"));
   }

   @Override
   public int getStatusPatternStatusGroup() {
      checkForUpdate();
      return Integer.parseInt(props.getProperty("status.value.group"));
   }

   @Override
   public int getStatusPatternDateGroup() {
      checkForUpdate();
      return Integer.parseInt(props.getProperty("status.date.group"));
   }

   @Override
   public String getProxyHost() {
      checkForUpdate();
      return props.getProperty("proxy.host");
   }

   @Override
   public int getProxyPort() {
      return Integer.parseInt(props.getProperty("proxy.port"));
   }

   @Override
   public boolean useProxy() {
      checkForUpdate();
      return Boolean.valueOf(props.getProperty("proxy.set"));
   }

   @Override
   public boolean useAuth() {
      checkForUpdate();
      return Boolean.valueOf(props.getProperty("server.basic.auth"));
   }

   @Override
   public String getServerUsername() {
      checkForUpdate();
      return props.getProperty("server.username");
   }

   @Override
   public String getServerPassword() {
      checkForUpdate();
      return props.getProperty("server.password");
   }

   @Override
   public String getTrustStore() {
      checkForUpdate();
      return props.getProperty("server.trust.store.location");
   }

   @Override
   public String getTrustStorePassword() {
      checkForUpdate();
      return props.getProperty("server.trust.store.password");
   }

   @Override
   public boolean useTrustStore() {
      checkForUpdate();
      return Boolean.valueOf(props.getProperty("server.trust.store"));
   }

}
